/*
 * hobie.inc
 *
 * POV-Ray scene description for Hobie Cat 16 catamaran
 *
 * Copyright (c) 1991, 1992, 1994, 1996 Ville Saari
 *
 * Created:    Apr-91
 * Updated: 09-Jan-98
 *
 * Author:
 *
 *   Ville Saari
 *   Tallbergin puistotie 7 B 21
 *   00200 Helsinki
 *   FINLAND
 *
 *   EMail: vs@iki.fi
 */

#include "colors.inc"
#include "shapes.inc"

// some colours for hulls and sails

#declare lightyellow = colour rgb <1, 1, 0.1>
#declare lightblue   = colour rgb <0.16, 0.25, 1>
#declare magenta     = colour rgb <0.5, 0.0, 0.5>
#declare darkyellow  = colour rgb <0.36, 0.36, 0.04>
#declare orange      = colour rgb <1, 0.25, 0>

// texture for hulls

#declare gelcoat = texture
   {
   pigment { colour lightyellow }

   finish
      {
      specular 1
      roughness 0.01
      }
   }

// texture for some plastic parts

#declare black_plastic = texture
   {
   pigment { colour Black }

   finish
      {
      specular 1
      roughness 0.01
      }
   }

// texture for black anodized aluminium

#declare aluminium = texture
   {
   pigment { colour Black }

   finish
      {
      specular 1
      roughness 0.05
      }
   }

// texture for stainless steel parts

#declare steel = texture
   {
   pigment { colour rgb .6 }

   finish
      {
      reflection 0.4
      specular 1
      roughness 0.01
      }
   }

// the left hull

#declare hull = intersection
   {
   sphere // the left (outer) side
      {
      0, 1

      texture
         {
         gelcoat

         pigment
            {
            gradient <0, 1, 0>

            colour_map // yellow-orange-red-black stripe
               {
               [0.9440 colour lightyellow]
               [0.9440 colour Black      ]
               [0.9445 colour Black      ]
               [0.9445 colour Red        ]
               [0.9455 colour Red        ]
               [0.9455 colour orange     ]
               [0.9465 colour orange     ]
               [0.9465 colour Yellow     ]
               [0.9475 colour Yellow     ]
               [0.9475 colour lightyellow]
               }

            quick_colour lightyellow

            rotate <-1.4, 0, 75>
            }
         }

      scale <72.5, 36.25, 72.5>
      translate 71.5*x
      }

   sphere // the right (inner) side
      {
      0, 1

      scale <72.5, 24.1667, 72.5>
      translate -71.5*x
      }

   torus // the deck
      {
      74.3, 1.8 sturm

      rotate <0, 0, 90>
      translate <0, 70.774, -3.726>
      }

   plane // the back
      {
      <0, 0, -1>, 8.44
      }

   bounded_by
      {
      box { <-0.91, -3.9, -20.44>, <0.81, 0, 0>
      matrix <1, 0, 0, 0, 1, 0, 0, 0.075, 1, 0, 0, 12> }
      }

   scale <0.22, 0.16, 0.25>
   translate <-1.02, 0.55, 2.11>

   texture {gelcoat}
   }


// aluminium profile for mast etc.

#declare profile = intersection
   {
   union
      {
      object { Cylinder_Y }

      intersection
         {
         plane { z, -0.5}
         plane { x, 1 rotate 30*y}
         plane {-x, 1 rotate -30*y}
         }
      }

   plane {y, 1}
   plane {-y, 0}

   bounded_by { box { <-1, 0, -2>, <1, 1, 1> } }

   scale <0.04, 1, 0.04>

   texture {aluminium}
   }


// trampoline frame

#declare frame=union
   {
   union
      {
      intersection // front crossbar
         {
         torus
            {
            5.458, 0.025 sturm

            rotate 90*x
            scale <1, 1, 2>
            }

         plane
            {
            -x, 0
            rotate 10.9846491144*z
            }

         plane
            {
            x, 0
            rotate -10.9846491144*z
            }

         bounded_by { box { <-1.045, 5.333, -.05>, <1.045, 5.483, .05> } }

         translate <0, -5.358, 0>
         }

      cylinder // left sidebar
         {
         -2*z, 0, 1

         scale <0.04, 0.025, 1>
         translate -1.04*x
         }

      cylinder // right sidebar
         {
         -2*z, 0, 1

         scale <0.04, 0.025, 1>
         translate 1.04*x
         }

      cylinder // aft crossbar
         {
         -1.04*x, 1.04*x, 1

         scale <1, 0.025, 0.04>
         translate -2*z
         }

      sphere // left front corner
         {
         0, 1

         scale <0.04, 0.025, 0.05>
         translate -1.04*x
         }

      sphere // right front corner
         {
         0, 1

         scale <0.04, 0.025, 0.05>
         translate 1.04*x
         }

      sphere // left aft corner
         {
         0, 1

         scale <0.04, 0.025, 0.04>
         translate <-1.04, 0, -2>
         }

      sphere // right aft corner
         {
         0, 1

         scale <0.04, 0.025, 0.04>
         translate <1.04, 0, -2>
         }

      scale <1.05, 1, 1>
      }

   object // left front pylon
      {
      profile

      scale <1, 0.25, 1>
      translate <-1.04, -0.25, -0.04>
      }

   object // right front pylon
      {
      profile

      scale <1, 0.25, 1>
      translate <1.04, -0.25, -0.04>
      }

   object // left aft pylon
      {
      profile

      scale <1, 0.25, 1>
      translate <-1.04, -0.25, -1.93>
      }

   object // right aft pylon
      {
      profile

      scale <1, 0.25, 1>
      translate <1.04, -0.25, -1.93>
      }

   union // dolphin striker
      {
      cylinder { -0.12*y, 0.1*y, 0.009 }
      cylinder { -0.1*y, <-1.02, -0.01, 0>, 0.005 }
      cylinder { -0.1*y, <1.02, -0.01, 0>, 0.005 }

      texture {steel}
      }

   texture {aluminium}

   rotate -2*x
   translate <0, 0.48, 2.8>
   }

// Trampoline

#declare trampoline=union
   {
   union // main parts
      {
      smooth_triangle // right part
         {
         <0.08, 0.115, 0   >, <1, 10, -0.6>
         <1.04, 0.01,  0   >, <1, 20, -0.6>
         <0.08, 0,    -1.72>, <1, 20, -0.6>
         }

      smooth_triangle
         {
         <1.04, 0,    -1.72>, <0, 20,  0  >
         <1.04, 0.01,  0   >, <1, 20, -0.6>
         <0.08, 0,    -1.72>, <1, 20, -0.6>
         }

      smooth_triangle // left part
         {
         <-0.08, 0.115, 0   >, <-1, 10, -0.6>
         <-1.04, 0.01,  0   >, <-1, 20, -0.6>
         <-0.08, 0,    -1.72>, <-1, 20, -0.6>
         }

      smooth_triangle
         {
         <-1.04, 0,    -1.72>, < 0, 20,  0  >
         <-1.04, 0.01,  0   >, <-1, 20, -0.6>
         <-0.08, 0,    -1.72>, <-1, 20, -0.6>
         }

      texture
         {
         pigment
            {
            gradient x

            colour_map
               {
               [0.40 colour Yellow]
               [0.40 colour Black ]
               [0.45 colour Black ]
               [0.45 colour Yellow]
               }

            quick_colour Yellow
            }

         finish
            {
            specular 1
            roughness 0.08
            }

         normal { bumps 0.2 scale 0.003 }
         }
      }

   union // back part
      {
      triangle {<-1.04, 0, -1.88>, < 1.04, 0, -1.88>, <1.04, 0, -2>}
      triangle {<-1.04, 0, -1.88>, <-1.04, 0, -2   >, <1.04, 0, -2>}

      texture
         {
         pigment {colour Yellow}

         finish
            {
            specular 1
            roughness 0.08
            }

         normal { bumps 0.2 scale 0.003 }
         }
      }

   union // lacings
      {
      triangle {<-0.1,  0.116,  0  >, < 0.1,  0.116,  0  >, <0.1,  0.001, -1.7>}
      triangle {<-0.1,  0.116,  0  >, <-0.1,  0.001, -1.7>, <0.1,  0.001, -1.7>}
      triangle {<-1.04, 0.001, -1.7>, < 1.04, 0.001, -1.7>, <1.04, 0.001, -1.9>}
      triangle {<-1.04, 0.001, -1.7>, <-1.04, 0.001, -1.9>, <1.04, 0.001, -1.9>}

      texture
         {
         pigment
            {
            gradient <0, 0, 1>

            colour_map
               {
               [0.08 colour White]
               [0.08 colour Clear]
               }

            scale <0.141421356238, 1, 0.141421356238>
            rotate <0, 45, 0>
            translate <0, 0, 10>
            }
         }

      texture
         {
         pigment
            {
            gradient <0, 0, 1>

            colour_map
               {
               [0.08 colour White]
               [0.08 colour Clear]
               }

            quick_colour rgb .6

            scale <0.141421356238, 1, 0.141421356238>
            rotate <0, -45, 0>
            translate <0, 0, 10>
            }
         }
      }

   scale <1.05, 1, 1>
   rotate -2*x
   translate <0, 0.48, 2.8>
   }


// Paddle

#declare paddle = union
   {
   union // blade
      {
      intersection
         {
         sphere { -y, 1.01 inverse}
         sphere { -y, 1.015}
         sphere { 0 1 scale <0.1, 1, 0.2> }
         plane { -z, 0.1}

         bounded_by { box { <-0.1, -0.01, -0.1>, <0.1, 0.015, 0.2> }}
         }

      cylinder { 0.1*z, 0.23*z, 0.02 }

      texture
         {
         pigment {colour orange}

         finish
            {
            specular 1
            roughness 0.01
            }
         }
      }

   cylinder // stem
      {
      0.23*z, 1.25*z, 0.015

      texture {steel} // should be clear aluminium but this will do
      }

   cylinder // cap
      {
      1.25*z, 1.28*z, 0.018

      texture
         {
         pigment {colour White}

         finish
            {
            specular 1
            roughness 0.01
            }
         }
      }

   rotate -3.3*x
   translate <0, 0.015, -1.75>
   rotate -2*x
   translate <0, 0.48, 2.8>
   }

#ifndef(rudder_raise)
#declare rudder_raise=0
#end

#declare tiller_translate = transform
   {
   rotate rudder_raise*x*-90
   translate <0, 0.05, -0.09>
   rotate rudder_raise*x*90
   translate <0, -0.05, 0.09>
   }

// the left rudder

#declare rudder = union
   {
   union // rudder blade
      {
      intersection
         {
         plane
            {
            y, 0
            rotate -13.6*z
            translate 0.27*y
            }

         sphere
            {
            0, 1
            scale <0.015, 0.5, 0.11>
            rotate 3*x
            translate <0, -0.05, -0.12>
            }

         texture // almost black plastic
            {
            pigment { colour rgb 0.01 }

            finish
               {
               specular 1
               roughness 0.02
               }
            }

         translate <0, -0.19, 0.08>
         }

      cylinder // bolt
         {
         -0.03*x, 0.03*x, 0.008

         texture {steel}
         }

      rotate rudder_raise*x*90

      translate <0, 0.19, -0.08>
      }

   intersection // blade housing
      {
      plane {z, 0}

      plane
         {
         y, 0
         rotate -13.6*x
         translate 0.27*y
         }

      sphere
         {
         0, 1
         scale <0.028, 0.15, 0.15>
         translate 0.2*y
         }
      }

   union // tiller
      {
      cylinder // bolt
         {
         -0.035*x, 0.035*x, 0.008

         texture {steel}
         }

      sphere
         {
         0, 1

         scale <0.028, 0.04, 0.03>
         }

      union
         {
         cylinder { 0, 0.2*z, 0.025 }
         cylinder { 0.2*z, 0.4*z, 0.015 }

         union
            {
            cylinder { 0, 0.4*z, 0.015 }
            sphere { 0, 0.015}
            sphere { 0.4*z, 0.015 texture { steel } }

            rotate 15*y
            translate 0.4*z
            }

         rotate -13.6*x
         translate <0, 0.015, 0>
         }

      translate <0, 0.24, -0.17>
      transform tiller_translate
      }

   texture { aluminium }

   translate <-1.06, 0.03, 0>
   }


// The tiller system

#declare tiller = union
   {
   union
      {
      cylinder { -0.9565*x, 0.9565*x, 0.015 }
      sphere { -0.9565*x, 0.015 texture { steel } }
      sphere { 0.9565*x, 0.015 texture { steel } }

      translate <0, 0.5, 0.6>
      }

   union
      {
      cylinder { 0, 1.7*z, 0.01 }
      sphere { 0, 0.01 texture {steel} }

      rotate <2+rudder_raise, -30, 0>
      translate <0, 0.525, 0.6>
      }

   transform tiller_translate

   texture {aluminium}
   }


// The mast

#declare mast = union
   {
   object { profile scale <1, 7.8, 1> }

   difference
      {
      cylinder { -0.015*x, 0.015*x, 0.08 }
      cylinder { -0.016*x, 0.016*x, 0.006 }

      translate <0, 7.86, -0.02>
      }

   texture {aluminium}
   }

// texture for main sail

#declare mainsailtexture = texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.197 colour lightyellow]
         [0.197 colour darkyellow ]
         [0.203 colour darkyellow ] // batten 8
         [0.203 colour lightyellow]
         [0.389 colour lightyellow]
         [0.389 colour rgb .4     ]
         }

      translate <0, -0.2, 0>
      rotate <0, 0, 15>
      translate <0, 0.794, 0>
      }
   }
texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.197 colour lightyellow]
         [0.197 colour darkyellow ]
         [0.203 colour darkyellow ] // batten 7
         [0.203 colour Clear      ]
         }

      translate <0, -0.2, 0>
      rotate <0, 0, 10>
      translate <0, 0.691, 0>
      }
   }
texture
   {
   pigment
      {
      image_map
         {
         iff "hc16.iff" once
         filter 0, 1
         use_colour
         }

      scale <0.4, 0.067, 1>
      translate 0.17*x
      rotate 6*z
      translate 0.603*y
      }
   }
texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.197 colour lightyellow]
         [0.197 colour darkyellow ]
         [0.203 colour darkyellow ] // batten 6
         [0.203 colour Clear      ]
         }

      translate <0, -0.2, 0>
      rotate <0, 0, 6>
      translate <0, 0.588, 0>
      }
   }
texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.197 colour lightyellow]
         [0.197 colour darkyellow ]
         [0.203 colour darkyellow ] // batten 5
         [0.203 colour Clear      ]
         }

      translate <0, -0.2, 0>
      rotate <0, 0, 3>
      translate <0, 0.485, 0>
      }
   }
texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.197 colour lightyellow]
         [0.197 colour darkyellow ]
         [0.203 colour darkyellow ] // batten 4
         [0.203 colour Clear      ]
         }

      translate <0, -0.2, 0>
      rotate <0, 0, 1>
      translate <0, 0.382, 0>
      }
   }
texture
   {
   pigment
      {
      gradient <0, 1, 0>

      colour_map
         {
         [0.071 colour lightyellow]
         [0.071 colour darkyellow ]
         [0.077 colour darkyellow ] // batten 1
         [0.077 colour lightblue  ]
         [0.108 colour lightblue  ]
         [0.108 colour Blue       ]
         [0.142 colour Blue       ]
         [0.142 colour magenta    ]
         [0.173 colour magenta    ]
         [0.173 colour red 0.6    ]
         [0.179 colour red 0.6    ] // batten 2
         [0.179 colour Red        ]
         [0.210 colour Red        ]
         [0.210 colour orange     ]
         [0.244 colour orange     ]
         [0.244 colour Yellow     ]
         [0.276 colour Yellow     ]
         [0.276 colour darkyellow ]
         [0.282 colour darkyellow ] // batten 3
         [0.282 colour Clear      ]
         }

      quick_colour lightyellow
      }

   finish
      {
      specular 0.1
      roughness 0.08
      }
   }


#declare sail_surface = bicubic_patch
   {
   type 1
   flatness 0.01
   u_steps 16
   v_steps 8

   <0, 1,   0>, <0.01,  1,   0.005>, <0.02, 1,   0.01>, <0.03, 1,   0.015>
   <0, 0.8, 0>, <0.2,   0.8, 0.2  >, <0.4,  0.8, 0.3 >, <0.8,  0.8, 0.3  >
   <0, 0.4, 0>, <0.275, 0.4, 0.255>, <0.55, 0.4, 0.31>, <1.1,  0.4, 0.22 >
   <0, 0,   0>, <0.35,  0,   0    >, <0.65, 0,   0   >, <1,    0,   0    >
   }

// the mainsail

#declare mainsail = union
   {
   object // left surface
      {
      sail_surface

      translate -0.0005*z

      texture {mainsailtexture}

      texture
         {
         pigment
            {
            image_map
               {
               iff "81469.iff" once
               filter 0, 1
               use_colour
               }

            quick_colour lightyellow
            }

         scale <0.66, 0.055, 1>
         translate 0.2*x
         rotate z
         translate 0.313*y
         }
      }

   object
      {
      sail_surface

      translate 0.0005*z

      texture { mainsailtexture }

      texture
         {
         pigment
            {
            image_map
               {
               iff "81469.iff" once
               filter 0, 1
               use_colour
               }

            quick_colour lightyellow
            }

         scale <-0.66, 0.055, 1>
         translate 0.77*x
         rotate z
         translate 0.397*y
         }
      }

   scale <2.6, 7.2, 2.8>
   rotate 90*y
   }

// The boom

#declare boom = union
   {
   cylinder
      {
      -0.025*z, -2.6*z, 1
      scale <0.025, 0.04, 1>
      }

   sphere
      {
      0, 1
      scale <0.025, 0.04, 0.025>
      translate -0.025*z
      }

   sphere
      {
      0, 1
      scale <0.025, 0.04, 0.025>
      translate -2.6*z
      }

   translate -0.04*y

   texture {aluminium}
   }

// the jib

#declare jib = intersection
   {
   object
      {
      Cylinder_Y
      scale <0.4, 1, 0.4>
      translate <0.2, 0, -0.3463>
      }

   object
      {
      Cylinder_Y
      scale <0.4, 1, 0.4>
      translate <0.2, 0, -0.3465>
      inverse
      }

   object
      {
      Cylinder_Z
      scale <2, 2, 1>
      translate <-1.6, -0.2, 0>
      }

   plane
      {
      <0, -1, 0>, 0
      rotate <0, 0, 7>
      }

   plane {<-1, 0, 0>, 0}

   texture
      {
      pigment
         {
         gradient <0, 1, 0>

         colour_map
            {
            [0.147 colour lightyellow]
            [0.147 colour darkyellow ]
            [0.155 colour darkyellow ] // batten 1
            [0.155 colour lightblue  ]
            [0.213 colour lightblue  ]
            [0.213 colour Blue       ]
            [0.275 colour Blue       ]
            [0.275 colour magenta    ]
            [0.333 colour magenta    ]
            [0.333 colour red 0.6    ]
            [0.341 colour red 0.6    ] // batten 2
            [0.341 colour Red        ]
            [0.399 colour Red        ]
            [0.399 colour orange     ]
            [0.461 colour orange     ]
            [0.461 colour Yellow     ]
            [0.519 colour Yellow     ]
            [0.519 colour darkyellow ]
            [0.527 colour darkyellow ] // batten 3
            [0.527 colour lightyellow]
            [0.705 colour lightyellow]
            [0.705 colour darkyellow ]
            [0.713 colour darkyellow ] // batten 4
            [0.713 colour lightyellow]
            }

         quick_colour lightyellow
         }

      finish
         {
         specular 0.1
         roughness 0.08
         }

      scale <1, 0.9848, 1>
      rotate <0, 0, 10>
      }

   bounded_by { box { <0, 0, -0.0001>, <0.4, 1, 0.055> } }

   scale <4.8, 4.4, 2>
   rotate <0, 90, 0>
   }


#declare wire = cylinder
   {
   0, y, 0.002

   texture {steel}
   }

#declare coated_wire = cylinder
   {
   0, y, 0.003

   texture
      {
      pigment {colour White}

      finish
         {
         specular 1
         roughness 0.01
         }
      }
   }

// the rigging

#declare rigging = union
   {
   union
      {
      object {mast}

      union
         {
         object { mainsail }
         object { boom }

         translate <0, 0.6, 0>
         rotate <0, 37, 0>
         translate <0, 0, -0.08>
         }

      rotate -45*y
      rotate -6.57*x
      translate <0, 0.605, 2.8>
      }

   union
      {
      object
         {
         wire
         scale <1, -1.2795, 1>
         rotate <0, 0, 52.86>
         }

      object
         {
         wire
         scale <1, -1.2795, 1>
         rotate <0, 0, -52.86>
         }

      object
         {
         wire
         scale <1, 5.39, 1>
         }

      object
         {
         jib
         rotate <0, -13, 0>
         translate <0, 0.15, 0>
         }

      translate 0.7725*y
      rotate -27.613*x
      translate <0, 0.54, 5.08>
      }

   object
      {
      coated_wire
      scale <1, -5.92, 1>
      rotate <0, 0, 11.653>
      translate <0, 6, 2.224>
      }

   object
      {
      coated_wire
      scale <1, -5.92, 1>
      rotate <0, 0, -11.653>
      translate <0, 6, 2.224>
      }
   }

// sheet block

#declare block = intersection
   {
   box { <-0.03, -0.031, -0.031>, <0.03, 0.031, 0.031> }

   object
      {
      Cylinder_X
      scale <1, 0.03, 0.03>

      texture {black_plastic}
      }

   texture {steel}
   }


// mainsail sheet

#declare mainsheet_length=.42

#declare mainsheet = union
   {
   object {block}
   object {block translate mainsheet_length*y }

   union
      {
      cylinder { 0, mainsheet_length*y, 0.006 translate < 0.02, 0,  0.024> }
      cylinder { 0, mainsheet_length*y, 0.006 translate < 0,    0,  0.024> }
      cylinder { 0, mainsheet_length*y, 0.006 translate <-0.02, 0,  0.024> }
      cylinder { 0, mainsheet_length*y, 0.006 translate < 0.02, 0, -0.024> }
      cylinder { 0, mainsheet_length*y, 0.006 translate < 0,    0, -0.024> }
      cylinder { 0, mainsheet_length*y, 0.006 translate <-0.02, 0, -0.024> }

      pigment { rgb .1 }
      }

   rotate -30*y
   rotate -20*x
   rotate -15*z

   translate <0.23, 0.468, 0.78>
   }

#declare mark=merge
{
cylinder { -y*.1, y*.1, 0.005 }
cylinder { -x*.1, x*.1, 0.005 }
cylinder { -z*.1, z*.1, 0.005 }
pigment { color rgbf <1, 1, 1, .7> }
}
#declare mark=sphere { 0, 0.005 pigment { color Red } }

#declare jibblock=union
   {
   object { block scale <1/6, 0.5, 0.5> }
   sphere { 0, 1 scale <.007, .02, .004> translate 0.015*y texture { steel } }
   translate -0.03*y 
   }

#declare jibsheet=union
   {
   union
      {
      box
         {
         <-.03, -.01, -.005>, <.03, .02, .005>

         rotate -4.7*z
         translate <.44, .59, 2.8>
         }

      box
         {
         <-.03, -.01, -.005>, <.03, .02, .005>

         rotate 4.7*z
         translate <-.44, .59, 2.8>
         }

      texture { black_plastic }
      }      

   object { jibblock rotate -25*y rotate 50*x translate <.432, .71, 2.965> }
   object { jibblock rotate 50*x rotate 80*y translate <.432, .71, 2.965> }

   union
      {
      cylinder { <.428, .681, 2.945>, <.425, .598, 2.8>, 0.004 }
      cylinder { <.436, .698, 2.936>, <.455, .595, 2.8>, 0.004 }

      intersection
         {
         box { <-.843, 0, -0.004>, <0, 0.13, 0.004> }
         torus { 3, .004 sturm rotate 90*x translate 3.004*y }

         rotate -10.55*y
         rotate 13.6*z
         translate <.41, .675, 2.96>
         }
      
      intersection
         {
         box { <-.864, 0, -0.004>, <0.005, 0.14, 0.004> }
         torus { 3, .004 sturm rotate 90*x translate 3.004*y }

         rotate -10.3*y
         rotate 15.2*z
         translate <.40, .695, 2.96>
         }
      
      sphere { <-.455, .5987, 2.805>, 0.004 }
      sphere { <-.425, .6012, 2.805>, 0.004 }

      pigment { rgb .1 }
      }
   }


// the boat:
//    heading to positive z,
//    x=0 and z=0 at center,
//    y=0 at waterline and
//    1 unit = 1m.

#declare hobie = union
   {
   object { hull }
   object { hull scale <-1, 1, 1> }
   object { frame }
   object { paddle }
   object { trampoline }
   object { rudder }
   object { rudder scale <-1, 1, 1> }
   object { tiller }
   object { rigging }
   object { mainsheet }
   object { jibsheet }

   translate -2.555*z
   }
